@@ -209,6 +209,8 @@ void ParseThread::startElement(const unsigned char *name, const unsigned char **
 
 	if(!stricmp((const char *)name, "echo"))
 		doLog((const char **)attrib, TEXT_ECHO);
+	else if(!stricmp((const char *)name, "answer"))
+		doAnswer();
 	else if(!stricmp((const char *)name, "text"))
 		doText((const char **)attrib);
 	else if(!stricmp((const char *)name, "goto"))
@@ -991,6 +993,11 @@ void ParseThread::doReorder(void)
 	img->addCompile(current, 1, "reorder", NULL);
 }
 
+void ParseThread::doAnswer(void)
+{
+	img->addCompile(current, 1, "answer", NULL);
+}
+
 void ParseThread::doHangup(void)
 {
 	img->addCompile(current, 0, "-hangup", NULL);
