@@ -3236,6 +3236,7 @@ class __EXPORT BayonneRPC : public Bayonne
 {
 protected:
 	BayonneRPC();
+	virtual ~BayonneRPC();
 
 	struct params
 	{
@@ -3250,6 +3251,8 @@ protected:
 	bool parseCall(char *cp);
 
 public:
+	virtual void setComplete(BayonneSession *s);
+
 	struct {
 		char *buffer;
 		size_t bufsize;
@@ -3277,6 +3280,7 @@ public:
 	inline unsigned getCount(void)
 		{return params.argc;};
 
+	const char *getParamId(unsigned short param, unsigned short offset); 
 	const char *getIndexed(unsigned short param, unsigned short offset = 0);
 	const char *getNamed(unsigned short param, const char *member);
 	const char *getMapped(const char *map, const char *member);
