@@ -366,6 +366,7 @@ unsigned BayonneTranslator::saycount(BayonneSession *s, unsigned count, const ch
 unsigned BayonneTranslator::spell(BayonneSession *s, unsigned count, const char *text) 
 {
 	char ch;
+	bool comma = false;
 
 	if(!text)
 		return count;
@@ -375,7 +376,10 @@ unsigned BayonneTranslator::spell(BayonneSession *s, unsigned count, const char
 		ch = tolower(*(text));
 		++text;
 		if(ch >= 'a' && ch <= 'z')
+		{
+			comma = true;
 			s->state.audio.list[count++] = letters[ch - 'a'];
+		}
 		else if(ch >= '0' && ch <= '9')
 			s->state.audio.list[count++] = numbers[ch - '0'];
 		
@@ -384,6 +388,10 @@ unsigned BayonneTranslator::spell(BayonneSession *s, unsigned count, const char
 		case '.':
 			s->state.audio.list[count++] = "dot";
 			break;
+		case ',':
+			if(comma)
+				s->state.audio.list[count++] = "comma";
+			break;
 		}
 	}
 	return count;
