@@ -36,9 +36,6 @@ BayonneDriver(driver, "/bayonne/driver/soundcard", "soundcard", false)
 {
 	const char *cp;
 
-	if(getUserdata())
-		load("~bayonne/soundcard");
-
 	device = atoi(getLast("device"));
 	active = Audio::hasDevice(device);
 	keyboard = NULL;
