@@ -41,17 +41,6 @@ static Keydata::Define defkeys[] = {
 	{"authenticate", "yes"},
     {NULL, NULL}};
 
-static bool isBit(unsigned char *bitmask, unsigned index)
-{
-	unsigned offset = index / 8;
-	unsigned char mask = 1 << (index % 8);
-
-	if(bitmask[offset] & mask)
-		return true;
-
-	return false;
-}
-
 Service::Service() :
 BayonneService(0, 0), 
 BayonneZeroconf("_http._tcp"),
@@ -118,7 +107,6 @@ void Service::postEvent(const char *buf, BayonneSession *s)
 	const char *uuid = s->getSymbol("session.uuid");
 	const char *aid = getRegistryId(s->getSymbol("session.authorized"));
 	const char *uid = getRegistryId(s->getSymbol("session.identity"));
-	unsigned tsid = atoi(s->getSessionId());
 
     EventStream::lock.enter();
     event = EventStream::first;
@@ -127,8 +115,6 @@ void Service::postEvent(const char *buf, BayonneSession *s)
 		next = event->next;
 		if(!event->isConnected())
 			goto disconnect;
-		if(!isBit(event->tsmap, tsid))
-			goto skip;
 		if(event->authorized[0])
 		{
 			if(uuid && !stricmp(uuid, event->authorized))
@@ -199,7 +185,9 @@ void Service::breakSession(BayonneSession *s)
 	xmlwrite(&bp, &max, 
 		"<session type=\"break\" id=%q>\r\n"
 		" <position>%s</position>\r\n",
-		s->getSessionId(), s->getSymbol("session.duration"));
+		" <reason>%s</reason>\r\n",
+		s->getSessionId(), s->getSymbol("session.duration"),
+		s->getSymbol("script.error"));
 
 	if(a)
 		xmlwrite(&bp, &max, " <connection>%s</connection>\r\n", a);
@@ -232,27 +220,60 @@ void Service::joinedSession(BayonneSession *s)
 	
 void Service::detachSession(BayonneSession *s)
 {
+	static char reply[1024];
 	char buf[256];
 	char *bp = buf;
 	size_t max = sizeof(buf);
 	const char *reason = s->getSymbol("session.exit_reason");
+	const char *manager = s->getSymbol("session.exit_manager");
+	EventStream *event, *next;
 
 	if(!EventStream::first)
 		return;
 
 	if(!reason || !*reason)
-		reason = "unknown";
+		reason = s->getSymbol("script.error");
 
 	xmlwrite(&bp, &max,
 		"<session type=\"exit\" id=%q>\r\n"
 		" <position>%s</position>\r\n"
 		" <reason>%s</reason>\r\n"
 		"</session>\r\n",
-				s->getSessionId(), 
+				s->getSessionId(),
 				s->getSymbol("session.duration"),
 				reason);
 
 	postEvent(buf, s);
+
+	if(!manager || stricmp(manager, "webservice"))
+		return;
+
+	EventStream::lock.enter();
+	event = EventStream::first;
+	while(event)
+	{
+		next = event->next;
+		if(!stricmp(event->authorized, s->getSessionId()))
+		{
+			bp = reply;
+			max = sizeof(reply);
+			xmlwrite(&bp, &max, 		
+				"<?xml version=\"1.0\"?>\r\n"
+				"<methodResponse><params><param><value><struct>\r\n"
+				" <member><name>session</name>\r\n"
+				"  <value><string>%s</string></value></member>\r\n"
+				" <member><name>reason</name>\r\n"
+				"  <value><string>%s</string></value></member>\r\n"
+				" <member><name>complete</name>\r\n"
+				"  <value><boolean>1</boolean></value></member>\r\n"
+				"</struct></value></param></params></methodResponse>\r\n",
+				s->getSessionId(), reason);
+			event->sendReply(reply);
+			break;
+		}
+		event = next;
+	}
+	EventStream::lock.leave();
 }
 
 void Service::run(void)
