@@ -60,10 +60,33 @@ static void server_version(BayonneRPC *rpc)
         return;
     }
 	rpc->buildResponse("(ii)", 
-		"current", (rpcint_t)3,
+		"current", (rpcint_t)4,
 		"prior", (rpcint_t)0);
 }
 
+static void server_keymap(BayonneRPC *rpc)
+{
+	char keymap[257];
+	unsigned pos = 0;
+
+    if(rpc->getCount())
+    {
+        rpc->sendFault(3, "Invalid Parameters");
+        return;
+    }
+
+	memcpy(keymap, Bayonne::dtmf_keymap, 256);
+	while(pos < 256)
+	{
+		if(!keymap[pos])
+			keymap[pos] = '-';
+
+		++pos;
+	}
+	keymap[pos] = 0;
+	rpc->buildResponse("s", keymap);
+}
+
 static void server_update(BayonneRPC *rpc)
 {
     if(rpc->getCount())
@@ -163,6 +186,37 @@ done:
 		Bayonne::endImage(img);
 }
 
+static void server_isService(BayonneRPC *rpc)
+{
+	ScriptImage *img = Bayonne::useImage();
+	char buffer[80];
+	const char *id;
+	bool rtn = false;
+
+	if(rpc->getCount() != 1)
+	{
+		rpc->sendFault(3, "Invalid Parameters");
+		goto done;
+	}
+
+	id = rpc->getIndexed(1);
+	if(!id || !*id)
+	{
+		rpc->sendFault(4, "Script Missing");
+		goto done;
+	}
+
+	snprintf(buffer, sizeof(buffer), "service.%s", id);
+	if(img->getPointer(buffer))
+		rtn = true;
+
+	rpc->buildResponse("b", rtn);
+
+done:
+	if(img)
+		Bayonne::endImage(img);
+}
+
 static void server_isSelect(BayonneRPC *rpc)
 {
 	ScriptImage *img = Bayonne::useImage();
@@ -466,6 +520,8 @@ static Bayonne::RPCDefine dispatch[] = {
 		"Return server directory layout", "struct"},
 	{"status", server_status,
 		"Return bayonne runtime status information", "struct"},
+	{"keymap", server_keymap,
+		"Return server keymap configuration", "string"},
 	{"callstats", server_callstats,
 		"Return server global call stats", "struct"},
 	{"getInfo", server_getInfo,
@@ -488,6 +544,8 @@ static Bayonne::RPCDefine dispatch[] = {
 		"Clear global symbol", "boolean, string"},
 	{"createSymbol", server_createSymbol,
 		"Create global symbol of specified size", "boolean, string, int"},
+	{"isService", server_isService,
+		"Check if a given service is defined", "boolean, string"},
 	{"isScript", server_isScript,
 		"Check if a given script exists", "boolean, string"},
 	{"isSelect", server_isSelect,
