@@ -39,8 +39,8 @@ static void session_version(BayonneRPC *rpc)
         return;
     }
 	rpc->buildResponse("(ii)", 
-		"current", (rpcint_t)2,
-		"prior", (rpcint_t)0);
+		"current", (rpcint_t)3,
+		"prior", (rpcint_t)3);
 }
 
 static void session_connect(BayonneRPC *rpc)
@@ -115,7 +115,10 @@ static void session_create(BayonneRPC *rpc)
 	if(rpc->transport.authorized)
 		authorized = "xmlrpc";
 	else
-		authorized = rpc->transport.userid;
+	{
+		rpc->transportFault(401, "Not Authorized");
+		return;
+	}
 
 	if(!dialed || !*dialed)
 	{
@@ -150,23 +153,26 @@ static void session_create(BayonneRPC *rpc)
 	session->leave();
 }
 
-static void session_createv(BayonneRPC *rpc)
+static void session_start(BayonneRPC *rpc)
 {
 	const char *dialed, *script, *caller, *display, *authorized, *uuid;
+	const char *service;
 	BayonneSession *session;
-	char buf[80], mbuf[8];
-	char *ep;
-	const char *id, *value;
+	char buf[80];
+	const char *value;
 	unsigned member = 1;
+	Script::Line *line = NULL;
+	ScriptImage *img = NULL;
+	unsigned idx = 0;
 
-	if(rpc->getCount() != 2)
+	if(rpc->getCount() <1 || rpc->getCount() > 2)
 	{
 		rpc->sendFault(3, "Invalid Parameters");
 		return;
 	}
 
 	dialed = rpc->getNamed(1, "dialed");
-	script = rpc->getNamed(1, "script");
+	service = rpc->getNamed(1, "service");
 	caller = rpc->getNamed(1, "caller");
 	display = rpc->getNamed(1, "display");
 	uuid = rpc->getNamed(1, "uuid");
@@ -185,9 +191,30 @@ static void session_createv(BayonneRPC *rpc)
 		return;
 	}
 
+	if(!service || !*service)
+	{
+		rpc->sendFault(4, "Invalid Service");
+		return;
+	}
+
+	snprintf(buf, sizeof(buf), "service.%s", service);
+	img = Bayonne::useImage();
+	if(img)
+		line = (Script::Line *)img->getPointer(buf);
+
+	if(!line)
+	{
+        rpc->sendFault(5, "Unknown Service");
+		Bayonne::endImage(img);
+        return;
+	}
+
+	script = line->cmd;
+
 	if(!script || !*script)
 	{
 		rpc->sendFault(4, "Invalid script");
+		Bayonne::endImage(img);
 		return;
 	}
 
@@ -201,6 +228,7 @@ static void session_createv(BayonneRPC *rpc)
 	if(!session)
 	{
 		rpc->sendFault(5, "Destination not dialable");
+		Bayonne::endImage(img);
 		return;
 	}
 	if(uuid && *uuid)
@@ -208,28 +236,140 @@ static void session_createv(BayonneRPC *rpc)
 	session->setConst("session.exit_manager", "xmlrpc");
 	if(!rpc->transport.authorized)
 		session->setConst("session.authorized", authorized); 
-	rpc->buildResponse("s", session->getSessionId());
+	rpc->buildResponse("(sb)", 
+		"session", session->getSessionId(),
+		"complete", (rpcbool_t)0);
 
-	while(NULL != (value = rpc->getIndexed(2, member++)))
+	while(NULL != (value = rpc->getIndexed(2, member)))
 	{
-		if(strchr(value, '='))
-		{
-			id = value;
-			value = strchr(id, '=') + 1;
-		} else 
-		{
-			snprintf(mbuf, sizeof(mbuf), "%d", member - 1);
-			id = mbuf;
-		}
-		snprintf(buf, sizeof(buf), "param.%s", id);
-		ep = strchr(buf, '=');
-		if(ep)
-			*ep = 0;
-
+		snprintf(buf, sizeof(buf), "param.%s", rpc->getParamId(2, member));
 		session->setConst(buf, value);
+		++member;
+	}
+	while(idx < line->argc)
+	{
+		value = line->args[idx++];
+		if(!value)
+			break;
+
+		if(*value != '=')
+			continue;
+		snprintf(buf, sizeof(buf), "param.%s", ++value);
+		value = session->getContent(line->args[idx++]);
+		if(value)
+			session->setConst(buf, value);	
 	}
 
 	session->leave();
+	Bayonne::endImage(img);
+}
+
+static void session_service(BayonneRPC *rpc)
+{
+	const char *dialed, *script, *caller, *display, *authorized, *uuid;
+	const char *service;
+	BayonneSession *session;
+	char buf[80];
+	const char *value;
+	unsigned member = 1;
+	Script::Line *line = NULL;
+	ScriptImage *img = NULL;
+	unsigned idx = 0;
+
+	if(rpc->getCount() < 1 || rpc->getCount() > 2)
+	{
+		rpc->sendFault(3, "Invalid Parameters");
+		return;
+	}
+
+	dialed = rpc->getNamed(1, "dialed");
+	service = rpc->getNamed(1, "service");
+	caller = rpc->getNamed(1, "caller");
+	display = rpc->getNamed(1, "display");
+	uuid = rpc->getNamed(1, "uuid");
+
+	if(uuid && strrchr(uuid, ':'))
+		uuid = strrchr(uuid, ':') + 1;
+
+	if(rpc->transport.authorized)
+		authorized = "xmlrpc";
+	else
+		authorized = rpc->transport.userid;
+
+	if(!dialed || !*dialed)
+	{
+		rpc->sendFault(4, "Invalid destination");
+		return;
+	}
+
+	if(!service || !*service)
+	{
+		rpc->sendFault(4, "Invalid Service");
+		return;
+	}
+
+	snprintf(buf, sizeof(buf), "service.%s", service);
+	img = Bayonne::useImage();
+	if(img)
+		line = (Script::Line *)img->getPointer(buf);
+
+	if(!line)
+	{
+        rpc->sendFault(5, "Unknown Service");
+		Bayonne::endImage(img);
+        return;
+	}
+
+	script = line->cmd;
+
+	if(!script || !*script)
+	{
+		rpc->sendFault(4, "Invalid script");
+		Bayonne::endImage(img);
+		return;
+	}
+
+	if(caller && !*caller)
+		caller = NULL;
+
+	if(display && !*display)
+		display = NULL;
+
+	session = Bayonne::startDialing(dialed, script, caller, display, NULL, authorized);
+	if(!session)
+	{
+		rpc->sendFault(5, "Destination not dialable");
+		Bayonne::endImage(img);
+		return;
+	}
+	if(uuid && *uuid)
+		session->setConst("session.uuid", uuid);
+	if(!rpc->transport.authorized)
+		session->setConst("session.authorized", authorized); 
+
+	while(NULL != (value = rpc->getIndexed(2, member)))
+	{
+		snprintf(buf, sizeof(buf), "param.%s", rpc->getParamId(2, member));
+		session->setConst(buf, value);
+		++member;
+	}
+	while(idx < line->argc)
+	{
+		value = line->args[idx++];
+		if(!value)
+			break;
+
+		if(*value != '=')
+			continue;
+		snprintf(buf, sizeof(buf), "param.%s", ++value);
+		value = session->getContent(line->args[idx++]);
+		if(value)
+			session->setConst(buf, value);	
+	}
+	Bayonne::endImage(img);
+	rpc->setComplete(session);
+	session->setConst("session.exit_manager", "xmlrpc");
+	session->leave();
 }
 
 static void session_transfer(BayonneRPC *rpc)
@@ -470,7 +610,7 @@ static void session_clearSymbol(BayonneRPC *rpc)
 	session->leave();
 }
 
-static void session_drop(BayonneRPC *rpc)
+static void session_stop(BayonneRPC *rpc)
 {
 	BayonneSession *session = NULL;
 	const char *id;
@@ -756,8 +896,8 @@ static Bayonne::RPCDefine dispatch[] = {
 		"Get session exit code", "struct, string"},
 	{"list", session_list,
 		"List sessions active in server", "array"},
-	{"drop", session_drop,
-		"Drop active call session", "boolean, string"},
+	{"stop", session_stop,
+		"Stop active call session", "boolean, string"},
     {"hold", session_hold,
         "Put active call session on hold", "boolean, string"},
     {"holdJoined", session_holdJoined,
@@ -780,8 +920,10 @@ static Bayonne::RPCDefine dispatch[] = {
 		"Connect two endpoints", "string, struct"},
 	{"create", session_create,
 		"Create a new call session", "string, struct"},
-	{"createv", session_createv,
-		"Create a new session with params", "string, struct, list"},
+	{"start", session_start,
+		"Start a new service with params", "struct, struct, struct"},
+	{"service", session_service,
+		"Execute a service script with params", "struct, struct, struct"},
 	{"transfer", session_transfer,
 		"Transfer a call thru session", "boolean, string, string"},
 	{NULL, NULL, NULL, NULL}};
