@@ -35,6 +35,28 @@ const char *Checks::chkSay(Line *line, ScriptImage *img)
 	return NULL;
 }		
 
+const char *Checks::chkService(Line *line, ScriptImage *img)
+{
+	char buffer[80];
+	unsigned idx = 0;
+	const char *cp = getOption(line, &idx);
+
+	if(getMember(line))
+		return "service has no members";
+
+	if(!cp)
+		return "service requires name";
+
+	if(getOption(line, &idx))
+		return "service uses one name only";
+
+	snprintf(buffer, sizeof(buffer), "service.%s", cp);
+	line->scr.name = img->getCurrent();
+	line->cmd = line->scr.name->name;
+	img->setPointer(buffer, line);
+	return "";
+}
+
 const char *Checks::chkParam(Line *line, ScriptImage *img)
 {
 	unsigned idx = 0;
