@@ -45,6 +45,8 @@ ScriptRuntime()
                         (Check)&Checks::chkTone},
                 {"callback", false, (Method)&Methods::scrTone,
                         (Check)&Checks::chkTone},
+        {"service", true, (Method)&ScriptMethods::scrNop,
+            (Check)&Checks::chkService},
 		{"lang", true, (Method)&ScriptMethods::scrNop,
 			(Check)&Checks::chkLang},
 		{"languages", true, (Method)&ScriptMethods::scrNop,
